	
<?php
/**
 * @version    1.2.9
 * @package    Com_YendifVideoShare
 * @author     PluginsWare Interactive Pvt. Ltd <admin@yendifplayer.com>
 * @copyright  Copyright (c) 2012 - 2021 PluginsWare Interactive Pvt. Ltd. All Rights Reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

// Prevent direct access
defined( '_JEXEC' ) or die( 'Restricted access' );

if ( ! defined( 'DS' ) ) {
	define( 'DS', DIRECTORY_SEPARATOR );
}
 
require_once JPATH_ROOT . DS . 'administrator' . DS . 'components' . DS . 'com_yendifvideoshare' . DS . 'libraries' . DS . 'utils.php';

class YendifVideoSharePlayer {	

	public static function load( $config = array(), $params = '' ) {
		// Load component language file	
		$lang = JFactory::getLanguage();	
		$lang->load( 'com_yendifvideoshare', JPATH_SITE );

		// Import CSS		
		$document = JFactory::getDocument();
		$document->addStyleSheet( YendifVideoShareUtils::prepareURL( 'media/yendifvideoshare/assets/site/css/yendifvideoshare.css', 'text/css', 'screen' ) );

		// Get the player URL
		$src = self::getURL( $config );
			
		// Build player HTML
		$ratio = '';

		if ( isset( $config['ratio'] ) ) {
			$ratio = $config['ratio'];
		} elseif ( ! empty( $params ) ) {
			$ratio = $params->get( 'ratio', '' );
		}

		if ( empty( $ratio ) ) {
			$_config = YendifVideoShareUtils::getConfig();
			$ratio = $_config->ratio;
		}

		$html = sprintf( 
			'<div class="yendifplayer" style="padding-bottom: %s;"><iframe width="560" height="315" src="%s" frameborder="0" allow="accelerometer; autoplay; encrypted-media; gyroscope; picture-in-picture" allowfullscreen></iframe></div>', 
			( (float) $ratio * 100 ) . '%', 
			$src
		);

		// Return
		return $html;
	}

	public static function getURL( $config = array() ) {
		// Build player URL
		$query = array(
			'option' => 'com_yendifvideoshare',
			'view'   => 'player',
			'id'     => 0,
			'format' => 'raw'
		);
		
		if ( isset( $config['videoid'] ) ) {
			$query['id'] = (int) $config['videoid'];
		} else {
			$sources = array( 'mp4', 'mp4_hd', 'webm', 'ogv', 'youtube', 'vimeo', 'hls', 'dash', 'image', 'captions' );

			foreach ( $sources as $source ) {
				if ( isset( $config[ $source ] ) ) {
					$query[ $source ] = base64_encode( $config[ $source ] );
				}
			}
		}

		$properties = array( 'autoplay', 'loop', 'volume', 'playbtn', 'controlbar', 'playpause', 'currenttime', 'progress', 'duration', 'volumebtn', 'fullscreen', 'embed', 'share', 'autoplaylist', 'uid', 'Itemid' );

		foreach ( $properties as $property ) {
			if ( isset( $config[ $property ] ) ) {
				$query[ $property ] = (int) $config[ $property ];
			}
		}

		$src = JUri::root() . 'index.php?' . http_build_query( $query );

		// Return
		return $src;
	}

	public static function updateViews( $id ) {		
		$session = JFactory::getSession();
		
		$stored = array();		
		if ( $session->get( 'com_yendifvideoshare_views' ) ) {
			$stored = $session->get( 'com_yendifvideoshare_views' );
		}
		
		if ( ! in_array( $id, $stored ) ) {
		    $stored[] = $id;				
	 
			$db = JFactory::getDbo();

		 	$query = 'UPDATE #__yendifvideoshare_videos SET views=views+1 WHERE id=' . (int) $id;
    	 	$db->setQuery( $query );
		 	$db->execute();
		 
		 	$session->set( 'com_yendifvideoshare_views', $stored );
		}		
	}
	
}
