<?php
/**
 * @version    1.2.9
 * @package    Com_YendifVideoShare
 * @author     PluginsWare Interactive Pvt. Ltd <admin@yendifplayer.com>
 * @copyright  Copyright (c) 2012 - 2021 PluginsWare Interactive Pvt. Ltd. All Rights Reserved.
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

// Prevent direct access
defined( '_JEXEC' ) or die( 'Restricted access' );

class YendifVideoShareModelImport extends YendifVideoShareModel {
	
	public function getLists() {	
    	$lists = array();
          
		// Publishing state  
		$options = array();
		$options[] = JHTML::_( 'select.option', '', '-- ' . JText::_( 'YENDIF_VIDEO_SHARE_SELECT_STATUS' ) . ' --' );
		$options[] = JHTML::_( 'select.option', 1, JText::_( 'YENDIF_VIDEO_SHARE_PUBLISHED' ) );
		$options[] = JHTML::_( 'select.option', 0, JText::_( 'YENDIF_VIDEO_SHARE_UNPUBLISHED' ) );
		$lists['state'] = JHTML::_( 'select.genericlist', $options, 'import_state', 'class="required yendif-no-margin"', 'value', 'text' );
		 
		// Categories list  
		$categories = $this->getCategories();

		$options = array();
		$options[] = JHTML::_( 'select.option', '', '-- '.JText::_( 'YENDIF_VIDEO_SHARE_SELECT_CATEGORY' ) . ' --' );		
		foreach ( $categories as $item ) {
			$item->treename = JString::str_ireplace( '&#160;', '-', $item->treename );
			$options[] = JHTML::_( 'select.option', $item->id, $item->treename );
		}
		$lists['categories'] = JHTML::_( 'select.genericlist', $options, 'import_category', 'class="required yendif-no-margin"', 'value', 'text' );
		 
		// return
        return $lists;		
	}
	
	public function getCategories() {	
        $db = JFactory::getDbo();
		
		$query = 'SELECT * FROM #__yendifvideoshare_categories ORDER BY ordering ASC';
		
		$db->setQuery( $query );
		$mitems = $db->loadObjectList();
		
		$children = array();
		if ( $mitems ) {
			foreach ( $mitems as $v ) {
				$v->title = $v->name;
				$v->parent_id = $v->parent;
				$pt = $v->parent;				
				$list = @$children[ $pt ] ? $children[ $pt ] : array();
				array_push( $list, $v );
				$children[ $pt ] = $list;
			}
		}
		
		$list = JHTML::_( 'menu.treerecurse', 0, '', array(), $children, 9999, 0, 0 );
				
		return $list;		
	}
	
	public function saveApiKey() {	
	  	$app = JFactory::getApplication();
		$db  = JFactory::getDbo();
		
		$api_key = $app->input->get( 'google_api_key' );

		$query = 'SELECT id FROM #__yendifvideoshare_options WHERE name=' . $db->quote( 'google_api_key' );
		$db->setQuery( $query );
		$id = $db->loadResult();

		$row = new stdClass();			
		
		$row->name = 'google_api_key';
		$row->value = $api_key;		

		if ( $id ) {
			$row->id = $id;
			$db->updateObject( '#__yendifvideoshare_options', $row, 'id' );
		} else {
			$row->id = NULL;
			$db->insertObject( '#__yendifvideoshare_options', $row );
		}

      	$msg = JText::_( 'YENDIF_VIDEO_SHARE_CHANGES_SAVED' );
      	$link = 'index.php?option=com_yendifvideoshare&view=import';
  
	  	$app->redirect( $link, $msg, 'message' );		
	}
	
	public function insertVideos( $ids, $titles ) {			 
		$app = JFactory::getApplication();
		$db = JFactory::getDbo();
		 
		// Vars
		$catid    = $app->input->getInt( 'import_category' );
		$userid   = JFactory::getUser()->get( 'id' );
		$status   = $app->input->getInt( 'import_state' );
		$messages = array();
		 
		// Insert videos
		foreach ( $ids as $key => $id ) {			 
			$sql = "SELECT COUNT(id) from #__yendifvideoshare_videos where type=" . $db->quote( 'youtube' ) . " and youtube LIKE " . $db->quote( '%' . $id ) . " LIMIT 1";
			
			$db->setQuery( $sql );			
			$count = $db->loadResult();
			 
			if ( $count > 0 ) {			 
			 	$messages[] = '<span><i class="icon-cancel"></i> ' . JText::sprintf( 'YENDIF_VIDEO_SHARE_ALREADY_EXISTS', $titles[ $key ] ) . '</span>';			 
			} else {			 
				$title = YendifVideoShareUtils::safeString( str_replace( "'", "\'", $titles[ $key ] ) );
				 
				$row = new JObject();
				
   				$row->id        = NULL;
				$row->title     = $title;
   				$row->alias     = YendifVideoShareUtils::stringURLSafe( $title );
				$row->catid     = $catid;
				$row->type      = 'youtube';
				$row->youtube   = "https://www.youtube.com/watch?v=$id";
				$row->image     = "https://img.youtube.com/vi/$id/0.jpg";	
				$row->userid    = $userid;
				$row->published = $status;
				$row->preroll 	= -1;
				$row->postroll	= -1;
					
   				$db->insertObject( '#__yendifvideoshare_videos', $row );
				
				$messages[] = '<span><i class="icon-ok"></i> ' . JText::sprintf( 'YENDIF_VIDEO_SHARE_IMPORTED_SUCCESSFULLY', $titles[ $key ] ) . '</span>';				 
			}
			 
		}
		 
		echo implode( '<br>', $messages );
		exit;		 
	}
	
}