/**
 * @version     1.2.9
 * @package     com_yendifvideoshare
 * @copyright   Copyright (c) 2012 - 2021 PluginsWare Interactive Pvt. Ltd. All Rights Reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * @author      PluginsWare Interactive Pvt. Ltd <admin@yendifplayer.com>
 */

if ( typeof( yendif ) === 'undefined' ) {
    var yendif = {};
};

yendif.fields = {};
yendif.files = 0;

function onYendifVideoEnded( event ) {	
	if ( event.data.message == 'ON_YENDIFVIDEOSHARE_ENDED' ) {
		var id = event.data.id;
		var loop = event.data.loop;

		if ( id ) {
			var $playlistItems = jQuery( '.yendif-video-share-playlist-item', '#yendif-video-share-playlist-' + id );
			var activeIndex = jQuery( '.yendif-video-share-playlist-item.active', '#yendif-video-share-playlist-' + id ).data( 'index' );
			
			var nextIndex = ++activeIndex;
			if ( $playlistItems.length == nextIndex ) {
				if ( loop ) {
					nextIndex = 0;
				} else {
					nextIndex = -1;
				}
			}

			if ( nextIndex > -1 ) {
				jQuery( '.yendif-video-share-playlist-item', '#yendif-video-share-playlist-' + id ).eq( nextIndex ).trigger( 'click' );
			}
		}	
	}
}
	
jQuery( document ).ready(function() {	

	// Playlist
	jQuery( '.yendif-video-share-playlist-item' ).on( 'click', function( e ) {			
		var $container = jQuery( this ).closest( '.yendif-video-share-playlist' );

		var src = jQuery( this ).data( 'src' );
		$container.find( 'iframe' ).attr( 'src', src );

		$container.find( '.yendif-video-share-playlist-item' ).removeClass( 'active' );
		jQuery( this ).addClass( 'active' );
	});

	window.addEventListener( 'message', onYendifVideoEnded, false );

	// Magnific Popup 
	if( jQuery.fn.magnificPopup !== undefined ) {
		var yendif_ratio = parseFloat( jQuery(this).data('ratio') ) || 0.5625;
		jQuery('.yendif-popup-gallery').magnificPopup({ 
			delegate: 'li', // the selector for gallery item
			type: 'iframe',
			overflowY: 'auto',			
			removalDelay: 300,
			mainClass: 'yendif-video-share-popup',
			iframe: { // to create title, close, iframe, counter div's
				markup: '<div class="mfp-title-bar">' +
					'<div class="mfp-close" title="Close (Esc)"></div>' +
				'</div>' +							
				'<div class="mfp-iframe-scaler" style="padding-top:' + ( yendif_ratio * 100 ) + '%;" >' +            												
					'<iframe class="mfp-iframe" frameborder="0" allowfullscreen></iframe>' +																								
				'</div>'																								        			
			},		
			callbacks: { // to assign title 									
				markupParse: function(template, values, item) {						 							
					values.title = item.el.attr('data-title');					
				}																			
			},		
			gallery: { // to build gallery				
				enabled: true,
				navigateByImgClick: true,
				tPrev: 'Previous',
				tNext: 'Next'													
			}									
		});	
	};
	
	// Rating
	jQuery( 'body' ).on( 'click', 'a.yendif-rating-trigger', function( e ) {
		e.preventDefault();
		
		var rating  = jQuery( this ).data( 'value' ),		
			videoid = jQuery( this ).data( 'id' ),
			userid  = yendif.userid,
			base    = yendif.base;
	
		if( yendif.allow_guest_rating == 0 && userid == 0 ) {
			alert( yendif.alert_message );
			return false;
		};

		document.getElementById("yendif-ratings-widget").innerHTML = '<span class="yendif-preloader"></span>';
		var xmlhttp;

   		if( window.XMLHttpRequest ) {
   			xmlhttp = new XMLHttpRequest();
   		} else {
   			xmlhttp = new ActiveXObject("Microsoft.XMLHTTP");
   		};

   		xmlhttp.onreadystatechange = function() {
   			if( xmlhttp.readyState == 4 && xmlhttp.status == 200 ) {
				if( xmlhttp.responseText ) {		    
					document.getElementById("yendif-ratings-widget").innerHTML = xmlhttp.responseText;
				};
       		};
   		};	

		xmlhttp.open( "GET", base + "index.php?option=com_yendifvideoshare&view=ajax&task=ratings&format=raw&rating=" + rating + "&videoid=" + videoid, true );
   		xmlhttp.send();
			
		return false;		
	});
	
	// Likes & Dislikes
	jQuery( 'body' ).on( 'click', '.yendif-like-btn, .yendif-dislike-btn', function( e ) {
		e.preventDefault();
		
		var like    = jQuery( this ).data( 'like' ),
			dislike = jQuery( this ).data( 'dislike' ),
			videoid = jQuery( this ).data( 'id' ),
			userid  = yendif.userid,
			base    = yendif.base;
	
		if( yendif.allow_guest_like == 0 && userid == 0 ) {
			alert( yendif.alert_message );
			return false;
		};

		document.getElementById("yendif-likes-dislikes-widget").innerHTML = '<span class="yendif-preloader"></span>';
		var xmlhttp;

   		if( window.XMLHttpRequest ) {
   			xmlhttp = new XMLHttpRequest();
   		} else {
   			xmlhttp = new ActiveXObject("Microsoft.XMLHTTP");
   		};

   		xmlhttp.onreadystatechange = function() {
   			if( xmlhttp.readyState == 4 && xmlhttp.status == 200 ) {
				if( xmlhttp.responseText ) {	
					document.getElementById("yendif-likes-dislikes-widget").innerHTML = xmlhttp.responseText;
				};
       		};
   		};	

		xmlhttp.open( "GET", base + "index.php?option=com_yendifvideoshare&view=ajax&task=likes_dislikes&format=raw&likes=" + like + "&dislikes=" + dislike + "&videoid=" + videoid, true );
   		xmlhttp.send();
			
		return false;		
	});
	
	// Show or Hide media fields according to the "Type" selected
	jQuery( '#type', '.yendif-media-types' ).on( 'change', function() {	
		var num_fields = jQuery('.yendif-media-fields').length;
		var option = jQuery( this ).val();
		jQuery( '.yendif-media-fields' ).fadeOut( 200, function() {
			if( --num_fields > 0 ) return;
			jQuery( '.yendif-type-'+option ).fadeIn(200);
			
			jQuery( '.yendif-media-required' ).removeClass( 'required' );
			switch( option ) {
				case 'video':
					jQuery( '#mp4' ).addClass( 'required' );
					break;
				case 'rtmp':
					jQuery( '#hls' ).addClass( 'required' );
					break;
				default:
					jQuery( '#'+option ).addClass( 'required' );
			};
		});	
	}).change();
	
	// Show or Hide more video formats
	jQuery( '#yendif-more-formats' ).on( 'click', function( e ) {
		e.preventDefault();

		if( jQuery( '#yendif-more-text' ).hasClass( 'hide' ) ) {
			jQuery( '#yendif-more-text' ).removeClass( 'hide' );
			jQuery( '#yendif-less-text' ).addClass( 'hide' );
			jQuery( '#yendif-more-formats-container' ).addClass( 'hide' );
		} else {
			jQuery( '#yendif-more-text' ).addClass( 'hide' );
			jQuery( '#yendif-less-text' ).removeClass( 'hide' );
			jQuery( '#yendif-more-formats-container' ).removeClass( 'hide' );
		};
	});
	
	// Show or Hide browse button
	jQuery( '.yendif-media-uploader-widget input[type="radio"]' ).on( 'change', function() {
		jQuery( this ).closest( '.yendif-media-uploader-widget' ).find( 'button' ).toggle();
	});
	
	// Trigger upload
	jQuery( '.yendif-media-uploader-widget .yendif-browse-btn' ).on( 'click', function( e ) {
		var id = document.getElementById('yendif-insert-id').value,
			field = jQuery( this ).data( 'field' ),
			accept = jQuery( this ).data( 'accept' ),
			iframe_id = 'yendif-upload-iframe-'+field,
			base = yendif.base;
		
		if( typeof yendif.fields[ field ] === 'undefined' ) {
			yendif.fields[ field ] = true;
			
			jQuery( '#yendif-media-uploader' ).append( '<form name="yendif-upload-form-'+field+'" id="yendif-upload-form-'+field+'" target="'+iframe_id+'" action="'+base+'index.php?option=com_yendifvideoshare&view=upload&format=raw&id='+id+'&f='+field+'" method="post" enctype="multipart/form-data" encoding="multipart/form-data"><input type="file" name="upload_'+field+'" id="yendif-upload-field-'+field+'" class="yendif-upload-field"  accept="'+accept+'" data-field="'+field+'" /></form>' );
		};
		
		jQuery('#yendif-upload-field-'+field).trigger('click');		
	});
	
	// Do upload
	jQuery('body').on( 'change', '.yendif-upload-field', function() {		
		var field = jQuery( this ).data( 'field' );
		
		var $browse_button = jQuery( '#yendif-browse-btn-'+field ),			
			iframe_id = 'yendif-upload-iframe-'+field;
		
		jQuery( '#yendif-media-uploader' ).append( '<iframe id="'+iframe_id+'" name="'+iframe_id+'" width="0" height="0" border="0" style="width:0; height:0; border:0;"></iframe>' );
	
		window.frames[ iframe_id ].name = iframe_id;
	
		var $value_field = document.getElementById( field ),
			$form_elem   = document.getElementById( 'yendif-upload-form-'+field ),
			$file_elem   = document.getElementById( 'yendif-upload-field-'+field ),
			$iframe_elem = document.getElementById( iframe_id ),
			$resp_elem   = document.getElementById( 'yendif-upload-response-'+field );
		
		// Add event...
		var yendif_upload_handler = function() {		
			if( $iframe_elem.detachEvent ) {
				$iframe_elem.detachEvent("onload", yendif_upload_handler);
			} else {
				$iframe_elem.removeEventListener("load", yendif_upload_handler, false);
			};

			// Message from server...
			var content = null;
	
			if( $iframe_elem.contentWindow && $iframe_elem.contentWindow.document.body ) {
				content = $iframe_elem.contentWindow.document.body.innerHTML;
			} else if( $iframe_elem.document && $iframe_elem.document.body ) {
				content = $iframe_elem.document.body.innerHTML;
			} else if( $iframe_elem.contentDocument && $iframe_elem.contentDocument.body ) {
				content = $iframe_elem.contentDocument.body.innerHTML;
			};

			--yendif.files;
	
			if( content == '' ) content = 'unknown_error';
			
			if( /invalid_file_type|invalid_file_size|invalid_mime_type|error_moving_file|unknown_error/.test(content) ) {
				$value_field.value = '';
				$resp_elem.innerHTML = '<span class="yendif-upload-failed"></span>' + yendif.msg[content] + ' - <a href="javascript:void(0);" onclick="yendif_reset_upload(\''+field+'\');">' + yendif.msg['retry'] + '</a>';
			} else {
				$value_field.value = content;
				$resp_elem.innerHTML = '<span class="yendif-upload-success"></span>' + yendif.msg['success'] + ' - <a href="javascript:void(0);" onclick="yendif_reset_upload(\''+field+'\');">' + yendif.msg['reset'] + '</a>';
			};
			
		};

		if( $iframe_elem.addEventListener ) {
			$iframe_elem.addEventListener("load", yendif_upload_handler, true);
		};

		if( $iframe_elem.attachEvent ) {
			$iframe_elem.attachEvent("onload", yendif_upload_handler);
		};

		// Submit the form...	
		$form_elem.submit();
		++yendif.files;

		$browse_button.hide();
		var file_elem_path = $file_elem.value.substring($file_elem.value.lastIndexOf("\\") + 1, $file_elem.value.length);
		$resp_elem.innerHTML = '<span class="yendif-upload-preloader"></span>' + file_elem_path + ' - <a href="javascript:void(0);" onclick="yendif_abort_upload(\''+field+'\');">' + yendif.msg['cancel'] + '</a>';
	});
	
});

function yendif_abort_upload( field ) {
	var iframe_id = 'yendif-upload-iframe-'+field;
	
	var $browse_button = jQuery( '#yendif-browse-btn-'+field ),	
		$value_field   = document.getElementById( field ),
		$resp_elem     = document.getElementById( 'yendif-upload-response-'+field ),
		$iframe_elem   = document.getElementById( iframe_id );

	if( $iframe_elem.contentWindow.stop ) {
    	$iframe_elem.contentWindow.stop();
    } else {
    	$iframe_elem.contentWindow.document.execCommand('Stop');
    };
	
	--yendif.files;
	
	$browse_button.show();	
	$value_field.value   = '';
	$resp_elem.innerHTML = '';	
	$iframe_elem.parentNode.removeChild( $iframe_elem );
	
	return false;
};

function yendif_reset_upload( field ) {	
	var iframe_id = 'yendif-upload-iframe-'+field;
	
	var $browse_button = jQuery( '#yendif-browse-btn-'+field ),	
		$value_field   = document.getElementById( field ),
		$resp_elem     = document.getElementById( 'yendif-upload-response-'+field ),
		$iframe_elem   = document.getElementById( iframe_id );
		
	$browse_button.show();	
	$value_field.value   = '';
	$resp_elem.innerHTML = '';
	$iframe_elem.parentNode.removeChild( $iframe_elem );
	
	return false;
};